/********************************************************************************
** Form generated from reading UI file 'journaldConfigurationWidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_JOURNALDCONFIGURATIONWIDGET_H
#define UI_JOURNALDCONFIGURATIONWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTableWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_JournaldConfigurationWidget
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *groupBoxOptions;
    QGridLayout *gridLayout;
    QCheckBox *lastBootOnly;
    QComboBox *entriesTypeComboBox;
    QGroupBox *groupBoxRemoteJournals;
    QHBoxLayout *horizontalLayout;
    QTableWidget *remoteJournalsListWidget;
    QGridLayout *buttonsGridLayout;
    QSpacerItem *verticalSpacer;
    QPushButton *addAddressButton;
    QPushButton *removeAddressButton;
    QPushButton *modifyAddressButton;
    QSpacerItem *bottomSpacer;

    void setupUi(QWidget *JournaldConfigurationWidget)
    {
        if (JournaldConfigurationWidget->objectName().isEmpty())
            JournaldConfigurationWidget->setObjectName("JournaldConfigurationWidget");
        JournaldConfigurationWidget->resize(450, 350);
        verticalLayout = new QVBoxLayout(JournaldConfigurationWidget);
        verticalLayout->setObjectName("verticalLayout");
        groupBoxOptions = new QGroupBox(JournaldConfigurationWidget);
        groupBoxOptions->setObjectName("groupBoxOptions");
        gridLayout = new QGridLayout(groupBoxOptions);
        gridLayout->setObjectName("gridLayout");
        lastBootOnly = new QCheckBox(groupBoxOptions);
        lastBootOnly->setObjectName("lastBootOnly");

        gridLayout->addWidget(lastBootOnly, 0, 0, 1, 1);

        entriesTypeComboBox = new QComboBox(groupBoxOptions);
        entriesTypeComboBox->addItem(QString());
        entriesTypeComboBox->addItem(QString());
        entriesTypeComboBox->addItem(QString());
        entriesTypeComboBox->setObjectName("entriesTypeComboBox");

        gridLayout->addWidget(entriesTypeComboBox, 1, 0, 1, 1);


        verticalLayout->addWidget(groupBoxOptions);

        groupBoxRemoteJournals = new QGroupBox(JournaldConfigurationWidget);
        groupBoxRemoteJournals->setObjectName("groupBoxRemoteJournals");
        horizontalLayout = new QHBoxLayout(groupBoxRemoteJournals);
        horizontalLayout->setObjectName("horizontalLayout");
        remoteJournalsListWidget = new QTableWidget(groupBoxRemoteJournals);
        if (remoteJournalsListWidget->columnCount() < 3)
            remoteJournalsListWidget->setColumnCount(3);
        QTableWidgetItem *__qtablewidgetitem = new QTableWidgetItem();
        remoteJournalsListWidget->setHorizontalHeaderItem(0, __qtablewidgetitem);
        QTableWidgetItem *__qtablewidgetitem1 = new QTableWidgetItem();
        remoteJournalsListWidget->setHorizontalHeaderItem(1, __qtablewidgetitem1);
        QTableWidgetItem *__qtablewidgetitem2 = new QTableWidgetItem();
        __qtablewidgetitem2->setText(QString::fromUtf8("HTTPS"));
        remoteJournalsListWidget->setHorizontalHeaderItem(2, __qtablewidgetitem2);
        remoteJournalsListWidget->setObjectName("remoteJournalsListWidget");
        remoteJournalsListWidget->setEditTriggers(QAbstractItemView::NoEditTriggers);
        remoteJournalsListWidget->setSelectionMode(QAbstractItemView::SingleSelection);
        remoteJournalsListWidget->setSelectionBehavior(QAbstractItemView::SelectRows);
        remoteJournalsListWidget->verticalHeader()->setVisible(false);

        horizontalLayout->addWidget(remoteJournalsListWidget);

        buttonsGridLayout = new QGridLayout();
        buttonsGridLayout->setObjectName("buttonsGridLayout");
        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        buttonsGridLayout->addItem(verticalSpacer, 3, 0, 1, 1);

        addAddressButton = new QPushButton(groupBoxRemoteJournals);
        addAddressButton->setObjectName("addAddressButton");

        buttonsGridLayout->addWidget(addAddressButton, 0, 0, 1, 1);

        removeAddressButton = new QPushButton(groupBoxRemoteJournals);
        removeAddressButton->setObjectName("removeAddressButton");
        removeAddressButton->setEnabled(false);

        buttonsGridLayout->addWidget(removeAddressButton, 2, 0, 1, 1);

        modifyAddressButton = new QPushButton(groupBoxRemoteJournals);
        modifyAddressButton->setObjectName("modifyAddressButton");
        modifyAddressButton->setEnabled(false);

        buttonsGridLayout->addWidget(modifyAddressButton, 1, 0, 1, 1);


        horizontalLayout->addLayout(buttonsGridLayout);


        verticalLayout->addWidget(groupBoxRemoteJournals);

        bottomSpacer = new QSpacerItem(20, 31, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(bottomSpacer);


        retranslateUi(JournaldConfigurationWidget);

        QMetaObject::connectSlotsByName(JournaldConfigurationWidget);
    } // setupUi

    void retranslateUi(QWidget *JournaldConfigurationWidget)
    {
        groupBoxOptions->setTitle(tr2i18n("Journald options", nullptr));
        lastBootOnly->setText(tr2i18n("Display log entries from current boot only", nullptr));
        entriesTypeComboBox->setItemText(0, tr2i18n("Display all log entries", nullptr));
        entriesTypeComboBox->setItemText(1, tr2i18n("Display log entries of processes of the current user", nullptr));
        entriesTypeComboBox->setItemText(2, tr2i18n("Display log entries of system services and the kernel", nullptr));

        groupBoxRemoteJournals->setTitle(tr2i18n("Remote journals", nullptr));
        QTableWidgetItem *___qtablewidgetitem = remoteJournalsListWidget->horizontalHeaderItem(0);
        ___qtablewidgetitem->setText(tr2i18n("Address", nullptr));
        QTableWidgetItem *___qtablewidgetitem1 = remoteJournalsListWidget->horizontalHeaderItem(1);
        ___qtablewidgetitem1->setText(tr2i18n("Port", nullptr));
        addAddressButton->setText(tr2i18n("Add address", nullptr));
        removeAddressButton->setText(tr2i18n("Remove address", nullptr));
        modifyAddressButton->setText(tr2i18n("Modify address", nullptr));
        (void)JournaldConfigurationWidget;
    } // retranslateUi

};

namespace Ui {
    class JournaldConfigurationWidget: public Ui_JournaldConfigurationWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // JOURNALDCONFIGURATIONWIDGET_H

