/********************************************************************************
** Form generated from reading UI file 'journaldAddressDialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_JOURNALDADDRESSDIALOG_H
#define UI_JOURNALDADDRESSDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_JournaldAddressDialog
{
public:
    QVBoxLayout *verticalLayout;
    QGridLayout *gridLayout;
    QLabel *addressLabel;
    QLineEdit *addressLineEdit;
    QLabel *portLabel;
    QLineEdit *portLineEdit;
    QLabel *httpsLabel;
    QCheckBox *httpsCheckBox;
    QSpacerItem *verticalSpacer;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *JournaldAddressDialog)
    {
        if (JournaldAddressDialog->objectName().isEmpty())
            JournaldAddressDialog->setObjectName("JournaldAddressDialog");
        JournaldAddressDialog->resize(300, 164);
        verticalLayout = new QVBoxLayout(JournaldAddressDialog);
        verticalLayout->setObjectName("verticalLayout");
        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        addressLabel = new QLabel(JournaldAddressDialog);
        addressLabel->setObjectName("addressLabel");

        gridLayout->addWidget(addressLabel, 0, 0, 1, 1);

        addressLineEdit = new QLineEdit(JournaldAddressDialog);
        addressLineEdit->setObjectName("addressLineEdit");
        addressLineEdit->setInputMask(QString::fromUtf8(""));
        addressLineEdit->setText(QString::fromUtf8(""));
        addressLineEdit->setMaxLength(1000);

        gridLayout->addWidget(addressLineEdit, 0, 1, 1, 1);

        portLabel = new QLabel(JournaldAddressDialog);
        portLabel->setObjectName("portLabel");

        gridLayout->addWidget(portLabel, 1, 0, 1, 1);

        portLineEdit = new QLineEdit(JournaldAddressDialog);
        portLineEdit->setObjectName("portLineEdit");
        portLineEdit->setInputMask(QString::fromUtf8("99999"));
        portLineEdit->setText(QString::fromUtf8("19531"));
        portLineEdit->setMaxLength(5);

        gridLayout->addWidget(portLineEdit, 1, 1, 1, 1);

        httpsLabel = new QLabel(JournaldAddressDialog);
        httpsLabel->setObjectName("httpsLabel");
        httpsLabel->setText(QString::fromUtf8("HTTPS"));

        gridLayout->addWidget(httpsLabel, 2, 0, 1, 1);

        httpsCheckBox = new QCheckBox(JournaldAddressDialog);
        httpsCheckBox->setObjectName("httpsCheckBox");

        gridLayout->addWidget(httpsCheckBox, 2, 1, 1, 1);


        verticalLayout->addLayout(gridLayout);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        buttonBox = new QDialogButtonBox(JournaldAddressDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);
        buttonBox->setCenterButtons(false);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(JournaldAddressDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, JournaldAddressDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, JournaldAddressDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(JournaldAddressDialog);
    } // setupUi

    void retranslateUi(QDialog *JournaldAddressDialog)
    {
        addressLabel->setText(tr2i18n("Address", nullptr));
        portLabel->setText(tr2i18n("Port", nullptr));
        httpsCheckBox->setText(tr2i18n("Enable", nullptr));
        (void)JournaldAddressDialog;
    } // retranslateUi

};

namespace Ui {
    class JournaldAddressDialog: public Ui_JournaldAddressDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // JOURNALDADDRESSDIALOG_H

