/*
    SPDX-FileCopyrightText: 2007 Nicolas Ternisien <nicolas.ternisien@gmail.com>

    SPDX-License-Identifier: GPL-2.0-or-later
*/

#include "logModeFactory.h"

#include "ksystemlog_debug.h"

LogModeFactory::LogModeFactory()
{
}

LogModeFactory::~LogModeFactory()
{
}

#include "moc_logModeFactory.cpp"
