/****************************************************************************
** Meta object code from reading C++ file 'tabLogViewsWidget.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../ksystemlog-26.04.2/src/tabLogViewsWidget.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'tabLogViewsWidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17TabLogViewsWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto TabLogViewsWidget::qt_create_metaobjectdata<qt_meta_tag_ZN17TabLogViewsWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TabLogViewsWidget",
        "logManagerCreated",
        "",
        "LogManager*",
        "manager",
        "statusBarChanged",
        "message",
        "createTab",
        "duplicateTab",
        "closeTab",
        "moveTabLeft",
        "moveTabRight",
        "reloadCurrent",
        "reloadAll",
        "changeReloadingTab",
        "View*",
        "view",
        "reloading",
        "expandAllCurrentView",
        "collapseAllCurrentView",
        "selectAllCurrentView",
        "fileSaveCurrentView",
        "copyToClipboardCurrentView",
        "sendMailCurrentView",
        "printSelectionCurrentView",
        "printPreviewSelectionCurrentView",
        "changeTab",
        "QIcon",
        "icon",
        "label",
        "changeCurrentTab",
        "index",
        "changeTitleAddedLines",
        "showContextMenu",
        "QPoint",
        "cursorPosition",
        "QWidget*",
        "tab"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'logManagerCreated'
        QtMocHelpers::SignalData<void(LogManager *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'statusBarChanged'
        QtMocHelpers::SignalData<void(const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Slot 'createTab'
        QtMocHelpers::SlotData<LogManager *()>(7, 2, QMC::AccessPublic, 0x80000000 | 3),
        // Slot 'duplicateTab'
        QtMocHelpers::SlotData<LogManager *()>(8, 2, QMC::AccessPublic, 0x80000000 | 3),
        // Slot 'closeTab'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'moveTabLeft'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'moveTabRight'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'reloadCurrent'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'reloadAll'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'changeReloadingTab'
        QtMocHelpers::SlotData<void(View *, bool)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 }, { QMetaType::Bool, 17 },
        }}),
        // Slot 'expandAllCurrentView'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'collapseAllCurrentView'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'selectAllCurrentView'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'fileSaveCurrentView'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'copyToClipboardCurrentView'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'sendMailCurrentView'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'printSelectionCurrentView'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'printPreviewSelectionCurrentView'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'changeTab'
        QtMocHelpers::SlotData<void(View *, const QIcon &, const QString &)>(26, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 15, 16 }, { 0x80000000 | 27, 28 }, { QMetaType::QString, 29 },
        }}),
        // Slot 'changeCurrentTab'
        QtMocHelpers::SlotData<void(int)>(30, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 31 },
        }}),
        // Slot 'changeTitleAddedLines'
        QtMocHelpers::SlotData<void(View *, int)>(32, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 15, 2 }, { QMetaType::Int, 2 },
        }}),
        // Slot 'showContextMenu'
        QtMocHelpers::SlotData<void(const QPoint &)>(33, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 34, 35 },
        }}),
        // Slot 'showContextMenu'
        QtMocHelpers::SlotData<void(QWidget *, const QPoint &)>(33, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 36, 37 }, { 0x80000000 | 34, 35 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TabLogViewsWidget, qt_meta_tag_ZN17TabLogViewsWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject TabLogViewsWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QTabWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17TabLogViewsWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17TabLogViewsWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17TabLogViewsWidgetE_t>.metaTypes,
    nullptr
} };

void TabLogViewsWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TabLogViewsWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->logManagerCreated((*reinterpret_cast<std::add_pointer_t<LogManager*>>(_a[1]))); break;
        case 1: _t->statusBarChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: { LogManager* _r = _t->createTab();
            if (_a[0]) *reinterpret_cast<LogManager**>(_a[0]) = std::move(_r); }  break;
        case 3: { LogManager* _r = _t->duplicateTab();
            if (_a[0]) *reinterpret_cast<LogManager**>(_a[0]) = std::move(_r); }  break;
        case 4: _t->closeTab(); break;
        case 5: _t->moveTabLeft(); break;
        case 6: _t->moveTabRight(); break;
        case 7: _t->reloadCurrent(); break;
        case 8: _t->reloadAll(); break;
        case 9: _t->changeReloadingTab((*reinterpret_cast<std::add_pointer_t<View*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 10: _t->expandAllCurrentView(); break;
        case 11: _t->collapseAllCurrentView(); break;
        case 12: _t->selectAllCurrentView(); break;
        case 13: _t->fileSaveCurrentView(); break;
        case 14: _t->copyToClipboardCurrentView(); break;
        case 15: _t->sendMailCurrentView(); break;
        case 16: _t->printSelectionCurrentView(); break;
        case 17: _t->printPreviewSelectionCurrentView(); break;
        case 18: _t->changeTab((*reinterpret_cast<std::add_pointer_t<View*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QIcon>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 19: _t->changeCurrentTab((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 20: _t->changeTitleAddedLines((*reinterpret_cast<std::add_pointer_t<View*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 21: _t->showContextMenu((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 22: _t->showContextMenu((*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 22:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWidget* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TabLogViewsWidget::*)(LogManager * )>(_a, &TabLogViewsWidget::logManagerCreated, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TabLogViewsWidget::*)(const QString & )>(_a, &TabLogViewsWidget::statusBarChanged, 1))
            return;
    }
}

const QMetaObject *TabLogViewsWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TabLogViewsWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17TabLogViewsWidgetE_t>.strings))
        return static_cast<void*>(this);
    return QTabWidget::qt_metacast(_clname);
}

int TabLogViewsWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QTabWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 23)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 23;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 23)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 23;
    }
    return _id;
}

// SIGNAL 0
void TabLogViewsWidget::logManagerCreated(LogManager * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void TabLogViewsWidget::statusBarChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
QT_WARNING_POP
