/********************************************************************************
** Form generated from reading UI file 'logLevelSelectionDialogBase.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_LOGLEVELSELECTIONDIALOGBASE_H
#define UI_LOGLEVELSELECTIONDIALOGBASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_LogLevelSelectionDialogBase
{
public:
    QVBoxLayout *vboxLayout;
    QLabel *label;
    QListWidget *logLevelsList;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *LogLevelSelectionDialogBase)
    {
        if (LogLevelSelectionDialogBase->objectName().isEmpty())
            LogLevelSelectionDialogBase->setObjectName("LogLevelSelectionDialogBase");
        LogLevelSelectionDialogBase->resize(246, 292);
        LogLevelSelectionDialogBase->setModal(true);
        vboxLayout = new QVBoxLayout(LogLevelSelectionDialogBase);
        vboxLayout->setObjectName("vboxLayout");
        label = new QLabel(LogLevelSelectionDialogBase);
        label->setObjectName("label");

        vboxLayout->addWidget(label);

        logLevelsList = new QListWidget(LogLevelSelectionDialogBase);
        logLevelsList->setObjectName("logLevelsList");

        vboxLayout->addWidget(logLevelsList);

        buttonBox = new QDialogButtonBox(LogLevelSelectionDialogBase);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);
        buttonBox->setCenterButtons(false);

        vboxLayout->addWidget(buttonBox);

#if QT_CONFIG(shortcut)
        label->setBuddy(logLevelsList);
#endif // QT_CONFIG(shortcut)

        retranslateUi(LogLevelSelectionDialogBase);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, LogLevelSelectionDialogBase, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, LogLevelSelectionDialogBase, qOverload<>(&QDialog::reject));
        QObject::connect(logLevelsList, &QListWidget::itemDoubleClicked, LogLevelSelectionDialogBase, qOverload<>(&QDialog::accept));

        QMetaObject::connectSlotsByName(LogLevelSelectionDialogBase);
    } // setupUi

    void retranslateUi(QDialog *LogLevelSelectionDialogBase)
    {
        LogLevelSelectionDialogBase->setWindowTitle(tr2i18n("Selecting File Type", nullptr));
        label->setText(tr2i18n("Please select the type of this file:", nullptr));
#if QT_CONFIG(tooltip)
        logLevelsList->setToolTip(tr2i18n("<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Sans Serif'; font-size:9pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">List of existing log levels</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        logLevelsList->setWhatsThis(tr2i18n("<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Sans Serif'; font-size:9pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">This is the list of all existing log levels. </p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Please select one of them to be used for the files selected on the list.</p></body></html>", nullptr));
#endif // QT_CONFIG(whatsthis)
    } // retranslateUi

};

namespace Ui {
    class LogLevelSelectionDialogBase: public Ui_LogLevelSelectionDialogBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // LOGLEVELSELECTIONDIALOGBASE_H

