/****************************************************************************
** Meta object code from reading C++ file 'mainWindow.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../ksystemlog-26.04.2/src/mainWindow.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mainWindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10KSystemLog10MainWindowE_t {};
} // unnamed namespace

template <> constexpr inline auto KSystemLog::MainWindow::qt_create_metaobjectdata<qt_meta_tag_ZN10KSystemLog10MainWindowE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KSystemLog::MainWindow",
        "changeStatusBar",
        "",
        "text",
        "changeWindowTitle",
        "updateStatusBar",
        "prepareCreatedLogManager",
        "LogManager*",
        "logManager",
        "fileOpen",
        "showConfigurationDialog",
        "showDetailsDialog",
        "showLogMessageDialog",
        "showSearchBar",
        "findNext",
        "findPrevious",
        "updateSelection",
        "updateReloading",
        "toggleFilterBar",
        "toggleItemTooltip",
        "enabled",
        "toggleNewLinesDisplaying",
        "displayed",
        "toggleResumePauseParsing",
        "paused",
        "changeCurrentTab",
        "changeResumePauseAction",
        "selectLogModeAction",
        "recreateActions"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'changeStatusBar'
        QtMocHelpers::SlotData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'changeWindowTitle'
        QtMocHelpers::SlotData<void(const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'updateStatusBar'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'prepareCreatedLogManager'
        QtMocHelpers::SlotData<void(LogManager *)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Slot 'fileOpen'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'showConfigurationDialog'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'showDetailsDialog'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'showLogMessageDialog'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'showSearchBar'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'findNext'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'findPrevious'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateSelection'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateReloading'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toggleFilterBar'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toggleItemTooltip'
        QtMocHelpers::SlotData<void(bool)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 20 },
        }}),
        // Slot 'toggleNewLinesDisplaying'
        QtMocHelpers::SlotData<void(bool)>(21, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 22 },
        }}),
        // Slot 'toggleResumePauseParsing'
        QtMocHelpers::SlotData<void(bool)>(23, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 24 },
        }}),
        // Slot 'changeCurrentTab'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'changeResumePauseAction'
        QtMocHelpers::SlotData<void(bool)>(26, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 24 },
        }}),
        // Slot 'selectLogModeAction'
        QtMocHelpers::SlotData<void(bool)>(27, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'recreateActions'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MainWindow, qt_meta_tag_ZN10KSystemLog10MainWindowE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KSystemLog::MainWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<KXmlGuiWindow::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10KSystemLog10MainWindowE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10KSystemLog10MainWindowE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10KSystemLog10MainWindowE_t>.metaTypes,
    nullptr
} };

void KSystemLog::MainWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MainWindow *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->changeStatusBar((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->changeWindowTitle((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->updateStatusBar(); break;
        case 3: _t->prepareCreatedLogManager((*reinterpret_cast<std::add_pointer_t<LogManager*>>(_a[1]))); break;
        case 4: _t->fileOpen(); break;
        case 5: _t->showConfigurationDialog(); break;
        case 6: _t->showDetailsDialog(); break;
        case 7: _t->showLogMessageDialog(); break;
        case 8: _t->showSearchBar(); break;
        case 9: _t->findNext(); break;
        case 10: _t->findPrevious(); break;
        case 11: _t->updateSelection(); break;
        case 12: _t->updateReloading(); break;
        case 13: _t->toggleFilterBar(); break;
        case 14: _t->toggleItemTooltip((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 15: _t->toggleNewLinesDisplaying((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 16: _t->toggleResumePauseParsing((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 17: _t->changeCurrentTab(); break;
        case 18: _t->changeResumePauseAction((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 19: _t->selectLogModeAction((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 20: _t->recreateActions(); break;
        default: ;
        }
    }
}

const QMetaObject *KSystemLog::MainWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KSystemLog::MainWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10KSystemLog10MainWindowE_t>.strings))
        return static_cast<void*>(this);
    return KXmlGuiWindow::qt_metacast(_clname);
}

int KSystemLog::MainWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KXmlGuiWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 21)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 21;
    }
    return _id;
}
QT_WARNING_POP
