/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.11.1
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // ksystemlogui.rc
  0x0,0x0,0x2,0x17,
  0x28,
  0xb5,0x2f,0xfd,0x60,0x50,0x6,0x6d,0x10,0x0,0x6,0x19,0x4a,0x1e,0x30,0x73,0x1e,
  0x2d,0x4a,0x58,0xc4,0x94,0x88,0x84,0x1d,0x49,0x93,0x91,0xd7,0xae,0xf3,0x35,0xdb,
  0xee,0xeb,0x36,0x30,0x67,0x43,0xbe,0x30,0xc8,0x42,0x18,0x45,0x0,0x40,0x0,0x3f,
  0x0,0xbd,0x16,0xe5,0x22,0xd3,0xe8,0xfd,0xd5,0x82,0x61,0x63,0xe6,0x32,0x6a,0xe4,
  0x29,0x62,0xec,0xd0,0x9e,0x43,0x8b,0x9f,0x7e,0xe8,0xa6,0x25,0xd8,0xda,0xd8,0xdc,
  0x3b,0xc2,0xcf,0x95,0x9b,0xc6,0xa6,0x7,0x65,0x62,0x99,0xb0,0xae,0x8f,0x3d,0x24,
  0x16,0x4a,0x23,0xe2,0x8,0x44,0x0,0x49,0xd1,0xa,0x4,0x43,0x4b,0x44,0x6f,0x3a,
  0xb9,0xc3,0xa0,0x75,0x29,0xa2,0xe,0xa1,0xcf,0x21,0x85,0xbd,0xcf,0xee,0x73,0xa1,
  0x64,0xf5,0xf9,0xfe,0xe2,0x48,0xb9,0xd8,0x98,0x8f,0xf4,0x4a,0x1a,0xc,0x98,0xca,
  0x85,0xd0,0x2b,0xb8,0x2b,0x2f,0x9e,0xfe,0x3b,0x57,0xf2,0x64,0x30,0x8,0xb8,0x75,
  0xc8,0x13,0x8a,0x1e,0x8,0x69,0xad,0x40,0xfa,0x8b,0xff,0xdb,0x31,0x14,0xf1,0x5b,
  0x4a,0xd9,0xa2,0x20,0xd6,0x60,0x4c,0x89,0x5e,0x35,0x6b,0xd2,0xff,0x9b,0xba,0x64,
  0xd,0xba,0x53,0x26,0x3f,0x6c,0xc,0xb5,0xa9,0xba,0x72,0x28,0x8f,0x67,0xe8,0x8b,
  0xfd,0xcf,0x34,0xf3,0x7a,0xb2,0xf6,0x18,0x86,0x54,0xc7,0x2d,0xea,0xb0,0xe2,0xdf,
  0xaa,0xa1,0xac,0x97,0x7d,0xca,0xc3,0xb1,0xe2,0x71,0x17,0xdb,0xf3,0xb4,0x21,0xc5,
  0xce,0x9f,0x36,0x84,0xbe,0x0,0xa9,0xeb,0x83,0xa2,0x9f,0x7e,0x79,0xb1,0xe9,0xa4,
  0x75,0x25,0xc5,0x56,0xa5,0x3c,0x63,0xef,0x14,0x7b,0x2d,0x28,0xfa,0x76,0xe,0x6e,
  0x9c,0xd5,0x35,0x6f,0xfa,0x65,0xf1,0xba,0xad,0xfa,0x23,0x67,0xbe,0x2e,0xe4,0x38,
  0x79,0xc3,0xce,0xa7,0xb9,0x17,0x6,0x90,0x58,0x33,0xbc,0xc9,0x93,0x47,0xd6,0x26,
  0xbb,0x58,0xff,0xa,0x5d,0xa0,0x81,0xd,0x42,0x18,0x11,0x9d,0x24,0x59,0xf6,0xc,
  0x30,0x84,0x10,0xe7,0xaa,0xb8,0x1,0x48,0xdd,0x11,0x27,0xbc,0x4c,0x5,0x49,0x44,
  0x69,0x74,0x34,0x6f,0x21,0x7c,0x14,0x1a,0x8b,0x5,0x18,0x12,0x32,0x1c,0xe4,0x9c,
  0xc,0xb1,0xa8,0x87,0xaf,0xec,0xac,0xcc,0x4d,0x65,0xda,0x8,0xb7,0x2c,0xf1,0xc5,
  0x79,0x95,0x0,0x6d,0xf5,0x88,0xf,0x68,0x36,0x3,0x7c,0x2,0xff,0x92,0x6b,0x14,
  0x1d,0x1e,0x9f,0x69,0xe4,0x56,0xcb,0x98,0x9c,0x80,0x41,0xcc,0x4,0x85,0xc0,0x21,
  0x6,0xff,0x89,0x2e,0x9a,0x9c,0x70,0xdb,0x28,0x3c,0x78,0x4b,0xa0,0xad,0x4,0xa0,
  0xbd,0x52,0xc8,0xcd,0xa7,0x9a,0x9,0x86,0xc2,0xe5,0x4d,0x62,0xb8,0x20,0x40,0xae,
  0x62,0x29,0x3c,0x69,0x77,0xd8,0xd1,0x7e,0x3,0x7c,0xfa,0x2f,0xcc,0x40,0xba,0xb6,
  0xf7,0x54,0x81,0xdc,0x51,0xed,0xc3,0x75,0xbc,0xb5,0x8f,0x65,0x5c,0xa2,0xa,0x33,
  0xd0,0xea,0x67,0x9b,0x96,0x3a,0x4,0x11,0x6d,0x29,0xa4,0xe,0x31,0x67,0xd7,0x1c,
  0x50,0xa7,0x46,0x1d,0xf3,0xa5,0xb,0x71,0x59,0x2b,0x1b,0x83,0x64,0x1f,0x4,0xdb,
  0xf8,0xb5,0xc2,0x59,0xe,0x35,0xec,0x2,0x43,0x51,0x91,0x9b,0xf2,0xda,0x4e,0x62,
  0xe0,0xdc,0xce,0x84,0x6,0x31,0xab,0x18,0x30,0xf,0x41,0xf7,0xe9,0xfa,0x59,0x83,
  0x0,0x90,0x41,0x40,0xa8,0x2,
  
};

static const unsigned char qt_resource_name[] = {
  // kxmlgui5
  0x0,0x8,
  0xf,0x42,0xe5,0x85,
  0x0,0x6b,
  0x0,0x78,0x0,0x6d,0x0,0x6c,0x0,0x67,0x0,0x75,0x0,0x69,0x0,0x35,
    // ksystemlog
  0x0,0xa,
  0xa,0xa6,0x95,0x57,
  0x0,0x6b,
  0x0,0x73,0x0,0x79,0x0,0x73,0x0,0x74,0x0,0x65,0x0,0x6d,0x0,0x6c,0x0,0x6f,0x0,0x67,
    // ksystemlogui.rc
  0x0,0xf,
  0x4,0xbf,0x97,0x23,
  0x0,0x6b,
  0x0,0x73,0x0,0x79,0x0,0x73,0x0,0x74,0x0,0x65,0x0,0x6d,0x0,0x6c,0x0,0x6f,0x0,0x67,0x0,0x75,0x0,0x69,0x0,0x2e,0x0,0x72,0x0,0x63,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x9e,0x92,0x21,0x99,0x40,
  // :/kxmlgui5
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x9e,0x92,0x21,0x99,0x40,
  // :/kxmlgui5/ksystemlog
  0x0,0x0,0x0,0x16,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x9e,0x92,0x21,0x99,0x40,
  // :/kxmlgui5/ksystemlog/ksystemlogui.rc
  0x0,0x0,0x0,0x30,0x0,0x4,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x9e,0x92,0x21,0x99,0x40,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#if defined(__ELF__) || defined(__APPLE__)
static inline unsigned char qResourceFeatureZstd()
{
    extern const unsigned char qt_resourceFeatureZstd;
    return qt_resourceFeatureZstd;
}
#else
unsigned char qResourceFeatureZstd();
#endif

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_ksystemlogui)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_ksystemlogui)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_ksystemlogui)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_ksystemlogui)()
{
    int version = 3;
    version += QT_RCC_PREPEND_NAMESPACE(qResourceFeatureZstd());
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_ksystemlogui)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_ksystemlogui)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif
