/********************************************************************************
** Form generated from reading UI file 'logViewSearchWidgetBase.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_LOGVIEWSEARCHWIDGETBASE_H
#define UI_LOGVIEWSEARCHWIDGETBASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_LogViewSearchWidgetBase
{
public:
    QHBoxLayout *hboxLayout;
    QPushButton *closeButton;
    QLabel *searchLabel;
    QLineEdit *searchLine;
    QPushButton *next;
    QPushButton *previous;
    QCheckBox *caseSensitive;
    QCheckBox *highlightAllButton;
    QLabel *messageIcon;
    QLabel *message;
    QSpacerItem *spacerItem;

    void setupUi(QWidget *LogViewSearchWidgetBase)
    {
        if (LogViewSearchWidgetBase->objectName().isEmpty())
            LogViewSearchWidgetBase->setObjectName("LogViewSearchWidgetBase");
        LogViewSearchWidgetBase->resize(705, 27);
        hboxLayout = new QHBoxLayout(LogViewSearchWidgetBase);
#ifndef UI_Q_OS_MAC
        hboxLayout->setSpacing(-1);
#endif
        hboxLayout->setObjectName("hboxLayout");
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        closeButton = new QPushButton(LogViewSearchWidgetBase);
        closeButton->setObjectName("closeButton");
        closeButton->setFlat(true);

        hboxLayout->addWidget(closeButton);

        searchLabel = new QLabel(LogViewSearchWidgetBase);
        searchLabel->setObjectName("searchLabel");

        hboxLayout->addWidget(searchLabel);

        searchLine = new QLineEdit(LogViewSearchWidgetBase);
        searchLine->setObjectName("searchLine");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(searchLine->sizePolicy().hasHeightForWidth());
        searchLine->setSizePolicy(sizePolicy);

        hboxLayout->addWidget(searchLine);

        next = new QPushButton(LogViewSearchWidgetBase);
        next->setObjectName("next");
        next->setFlat(true);

        hboxLayout->addWidget(next);

        previous = new QPushButton(LogViewSearchWidgetBase);
        previous->setObjectName("previous");
        previous->setFlat(true);

        hboxLayout->addWidget(previous);

        caseSensitive = new QCheckBox(LogViewSearchWidgetBase);
        caseSensitive->setObjectName("caseSensitive");

        hboxLayout->addWidget(caseSensitive);

        highlightAllButton = new QCheckBox(LogViewSearchWidgetBase);
        highlightAllButton->setObjectName("highlightAllButton");

        hboxLayout->addWidget(highlightAllButton);

        messageIcon = new QLabel(LogViewSearchWidgetBase);
        messageIcon->setObjectName("messageIcon");

        hboxLayout->addWidget(messageIcon);

        message = new QLabel(LogViewSearchWidgetBase);
        message->setObjectName("message");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(message->sizePolicy().hasHeightForWidth());
        message->setSizePolicy(sizePolicy1);

        hboxLayout->addWidget(message);

        spacerItem = new QSpacerItem(40, 20, QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Minimum);

        hboxLayout->addItem(spacerItem);


        retranslateUi(LogViewSearchWidgetBase);

        QMetaObject::connectSlotsByName(LogViewSearchWidgetBase);
    } // setupUi

    void retranslateUi(QWidget *LogViewSearchWidgetBase)
    {
        closeButton->setText(QString());
        searchLabel->setText(tr2i18n("Find:", nullptr));
        next->setText(tr2i18n("&Next", nullptr));
        previous->setText(tr2i18n("&Previous", nullptr));
        caseSensitive->setText(tr2i18n("Match &case", nullptr));
        highlightAllButton->setText(tr2i18n("&Highlight all", nullptr));
        messageIcon->setText(QString());
        message->setText(QString());
        (void)LogViewSearchWidgetBase;
    } // retranslateUi

};

namespace Ui {
    class LogViewSearchWidgetBase: public Ui_LogViewSearchWidgetBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // LOGVIEWSEARCHWIDGETBASE_H

