/********************************************************************************
** Form generated from reading UI file 'generalConfigurationWidgetBase.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_GENERALCONFIGURATIONWIDGETBASE_H
#define UI_GENERALCONFIGURATIONWIDGETBASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_GeneralConfigurationWidgetBase
{
public:
    QVBoxLayout *vboxLayout;
    QGroupBox *startupModeGroupbox;
    QVBoxLayout *startupModeVerticalLayout;
    QHBoxLayout *startupModeHorizontalLayout;
    QLabel *startupModeLabel;
    QComboBox *startupLogMode;
    QGroupBox *linesNumberGroupbox;
    QVBoxLayout *vboxLayout1;
    QHBoxLayout *linesNumberLayout;
    QLabel *maxLinesLabel;
    QSpinBox *maxLines;
    QCheckBox *deleteDuplicatedLines;
    QGroupBox *optionsGroupbox;
    QVBoxLayout *vboxLayout2;
    QCheckBox *deleteProcessId;
    QCheckBox *colorizeLogLines;
    QGroupBox *dateFormatGroupbox;
    QVBoxLayout *vboxLayout3;
    QRadioButton *formatShortDate;
    QRadioButton *formatLongDate;
    QRadioButton *formatPreciseDate;
    QSpacerItem *bottomSpacer;

    void setupUi(QWidget *GeneralConfigurationWidgetBase)
    {
        if (GeneralConfigurationWidgetBase->objectName().isEmpty())
            GeneralConfigurationWidgetBase->setObjectName("GeneralConfigurationWidgetBase");
        GeneralConfigurationWidgetBase->resize(368, 497);
        vboxLayout = new QVBoxLayout(GeneralConfigurationWidgetBase);
        vboxLayout->setObjectName("vboxLayout");
        startupModeGroupbox = new QGroupBox(GeneralConfigurationWidgetBase);
        startupModeGroupbox->setObjectName("startupModeGroupbox");
        startupModeVerticalLayout = new QVBoxLayout(startupModeGroupbox);
        startupModeVerticalLayout->setObjectName("startupModeVerticalLayout");
        startupModeHorizontalLayout = new QHBoxLayout();
        startupModeHorizontalLayout->setObjectName("startupModeHorizontalLayout");
        startupModeLabel = new QLabel(startupModeGroupbox);
        startupModeLabel->setObjectName("startupModeLabel");

        startupModeHorizontalLayout->addWidget(startupModeLabel);

        startupLogMode = new QComboBox(startupModeGroupbox);
        startupLogMode->setObjectName("startupLogMode");

        startupModeHorizontalLayout->addWidget(startupLogMode);


        startupModeVerticalLayout->addLayout(startupModeHorizontalLayout);


        vboxLayout->addWidget(startupModeGroupbox);

        linesNumberGroupbox = new QGroupBox(GeneralConfigurationWidgetBase);
        linesNumberGroupbox->setObjectName("linesNumberGroupbox");
        vboxLayout1 = new QVBoxLayout(linesNumberGroupbox);
        vboxLayout1->setObjectName("vboxLayout1");
        linesNumberLayout = new QHBoxLayout();
        linesNumberLayout->setObjectName("linesNumberLayout");
        maxLinesLabel = new QLabel(linesNumberGroupbox);
        maxLinesLabel->setObjectName("maxLinesLabel");

        linesNumberLayout->addWidget(maxLinesLabel);

        maxLines = new QSpinBox(linesNumberGroupbox);
        maxLines->setObjectName("maxLines");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(maxLines->sizePolicy().hasHeightForWidth());
        maxLines->setSizePolicy(sizePolicy);
        maxLines->setMinimum(10);
        maxLines->setMaximum(30000);
        maxLines->setSingleStep(10);

        linesNumberLayout->addWidget(maxLines);


        vboxLayout1->addLayout(linesNumberLayout);

        deleteDuplicatedLines = new QCheckBox(linesNumberGroupbox);
        deleteDuplicatedLines->setObjectName("deleteDuplicatedLines");

        vboxLayout1->addWidget(deleteDuplicatedLines);


        vboxLayout->addWidget(linesNumberGroupbox);

        optionsGroupbox = new QGroupBox(GeneralConfigurationWidgetBase);
        optionsGroupbox->setObjectName("optionsGroupbox");
        vboxLayout2 = new QVBoxLayout(optionsGroupbox);
        vboxLayout2->setObjectName("vboxLayout2");
        deleteProcessId = new QCheckBox(optionsGroupbox);
        deleteProcessId->setObjectName("deleteProcessId");

        vboxLayout2->addWidget(deleteProcessId);

        colorizeLogLines = new QCheckBox(optionsGroupbox);
        colorizeLogLines->setObjectName("colorizeLogLines");

        vboxLayout2->addWidget(colorizeLogLines);


        vboxLayout->addWidget(optionsGroupbox);

        dateFormatGroupbox = new QGroupBox(GeneralConfigurationWidgetBase);
        dateFormatGroupbox->setObjectName("dateFormatGroupbox");
        vboxLayout3 = new QVBoxLayout(dateFormatGroupbox);
        vboxLayout3->setObjectName("vboxLayout3");
        formatShortDate = new QRadioButton(dateFormatGroupbox);
        formatShortDate->setObjectName("formatShortDate");

        vboxLayout3->addWidget(formatShortDate);

        formatLongDate = new QRadioButton(dateFormatGroupbox);
        formatLongDate->setObjectName("formatLongDate");

        vboxLayout3->addWidget(formatLongDate);

        formatPreciseDate = new QRadioButton(dateFormatGroupbox);
        formatPreciseDate->setObjectName("formatPreciseDate");

        vboxLayout3->addWidget(formatPreciseDate);


        vboxLayout->addWidget(dateFormatGroupbox);

        bottomSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(bottomSpacer);

#if QT_CONFIG(shortcut)
        startupModeLabel->setBuddy(startupLogMode);
        maxLinesLabel->setBuddy(maxLines);
#endif // QT_CONFIG(shortcut)

        retranslateUi(GeneralConfigurationWidgetBase);

        QMetaObject::connectSlotsByName(GeneralConfigurationWidgetBase);
    } // setupUi

    void retranslateUi(QWidget *GeneralConfigurationWidgetBase)
    {
        startupModeGroupbox->setTitle(tr2i18n("Startup", nullptr));
        startupModeLabel->setText(tr2i18n("Load &this log mode at startup:", nullptr));
#if QT_CONFIG(tooltip)
        startupLogMode->setToolTip(tr2i18n("The log mode which is loaded by default at startup", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        startupLogMode->setWhatsThis(tr2i18n("The log mode loaded by default at startup. Choose 'No Log Mode' if you do not want this to happen.", nullptr));
#endif // QT_CONFIG(whatsthis)
        linesNumberGroupbox->setTitle(tr2i18n("Log Lines List", nullptr));
        maxLinesLabel->setText(tr2i18n("&Maximum lines displayed:", nullptr));
#if QT_CONFIG(tooltip)
        maxLines->setToolTip(tr2i18n("Choose here the maximum number of log lines displayed in the main view.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        maxLines->setWhatsThis(tr2i18n("You can choose here the maximum number of log lines displayed in the main view.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(tooltip)
        deleteDuplicatedLines->setToolTip(tr2i18n("Select this option if you want to delete duplicate log lines <b>(may be slow)</b>.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        deleteDuplicatedLines->setWhatsThis(tr2i18n("Select this option if you want to delete duplicate log lines. <b>This option can slow log reading</b>.", nullptr));
#endif // QT_CONFIG(whatsthis)
        deleteDuplicatedLines->setText(tr2i18n("Remove &duplicate log lines (may be slower)", nullptr));
        optionsGroupbox->setTitle(tr2i18n("Options", nullptr));
#if QT_CONFIG(tooltip)
        deleteProcessId->setToolTip(tr2i18n("Remove process identifier from process name.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        deleteProcessId->setWhatsThis(tr2i18n("Select this option if you want to remove the process identifier from the process name. For example, the <b>Process</b> column may contain entries such as <i>cron<b>[3433]</b></i>. If this option is activated, the bold part will be removed.", nullptr));
#endif // QT_CONFIG(whatsthis)
        deleteProcessId->setText(tr2i18n("Remove &identifier from process name", nullptr));
#if QT_CONFIG(tooltip)
        colorizeLogLines->setToolTip(tr2i18n("This option allows log lines to be colored depending on their log level.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        colorizeLogLines->setWhatsThis(tr2i18n("This option allows log lines to be colored depending on their log level. For example, errors will be shown in red, warnings in orange, and so on. This will help you to see problems more easily.", nullptr));
#endif // QT_CONFIG(whatsthis)
        colorizeLogLines->setText(tr2i18n("&Colored log lines", nullptr));
        dateFormatGroupbox->setTitle(tr2i18n("Date Format", nullptr));
        formatShortDate->setStyleSheet(QString());
        formatShortDate->setText(tr2i18n("&Short date format", nullptr));
        formatLongDate->setText(tr2i18n("&Long date format", nullptr));
        formatPreciseDate->setText(tr2i18n("&Precise date format", nullptr));
        (void)GeneralConfigurationWidgetBase;
    } // retranslateUi

};

namespace Ui {
    class GeneralConfigurationWidgetBase: public Ui_GeneralConfigurationWidgetBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // GENERALCONFIGURATIONWIDGETBASE_H

