/********************************************************************************
** Form generated from reading UI file 'detailDialogBase.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DETAILDIALOGBASE_H
#define UI_DETAILDIALOGBASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <klocalizedstring.h>
#include "ktextedit.h"

QT_BEGIN_NAMESPACE

class Ui_DetailDialogBase
{
public:
    QGridLayout *gridLayout;
    KTextEdit *message;
    QLabel *icon;
    QLabel *header;
    QHBoxLayout *hboxLayout;
    QPushButton *previous;
    QPushButton *next;
    QSpacerItem *spacerItem;
    QPushButton *closeButton;

    void setupUi(QDialog *DetailDialogBase)
    {
        if (DetailDialogBase->objectName().isEmpty())
            DetailDialogBase->setObjectName("DetailDialogBase");
        DetailDialogBase->resize(411, 248);
        gridLayout = new QGridLayout(DetailDialogBase);
        gridLayout->setObjectName("gridLayout");
        message = new KTextEdit(DetailDialogBase);
        message->setObjectName("message");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(message->sizePolicy().hasHeightForWidth());
        message->setSizePolicy(sizePolicy);
        message->setAcceptDrops(false);
        message->setUndoRedoEnabled(false);
        message->setReadOnly(true);
        message->setCheckSpellingEnabled(false);

        gridLayout->addWidget(message, 1, 0, 1, 2);

        icon = new QLabel(DetailDialogBase);
        icon->setObjectName("icon");
        sizePolicy.setHeightForWidth(icon->sizePolicy().hasHeightForWidth());
        icon->setSizePolicy(sizePolicy);
        icon->setWordWrap(false);

        gridLayout->addWidget(icon, 0, 0, 1, 1);

        header = new QLabel(DetailDialogBase);
        header->setObjectName("header");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Expanding);
        sizePolicy1.setHorizontalStretch(2);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(header->sizePolicy().hasHeightForWidth());
        header->setSizePolicy(sizePolicy1);
        header->setWordWrap(false);

        gridLayout->addWidget(header, 0, 1, 1, 1);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        previous = new QPushButton(DetailDialogBase);
        previous->setObjectName("previous");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(previous->sizePolicy().hasHeightForWidth());
        previous->setSizePolicy(sizePolicy2);
        previous->setProperty("stdItem", QVariant(14));

        hboxLayout->addWidget(previous);

        next = new QPushButton(DetailDialogBase);
        next->setObjectName("next");
        sizePolicy2.setHeightForWidth(next->sizePolicy().hasHeightForWidth());
        next->setSizePolicy(sizePolicy2);
        next->setProperty("stdItem", QVariant(15));

        hboxLayout->addWidget(next);

        spacerItem = new QSpacerItem(100, 31, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        hboxLayout->addItem(spacerItem);

        closeButton = new QPushButton(DetailDialogBase);
        closeButton->setObjectName("closeButton");
        sizePolicy2.setHeightForWidth(closeButton->sizePolicy().hasHeightForWidth());
        closeButton->setSizePolicy(sizePolicy2);
        closeButton->setProperty("stdItem", QVariant(13));

        hboxLayout->addWidget(closeButton);


        gridLayout->addLayout(hboxLayout, 2, 0, 1, 2);

        gridLayout->setRowStretch(1, 1);

        retranslateUi(DetailDialogBase);

        QMetaObject::connectSlotsByName(DetailDialogBase);
    } // setupUi

    void retranslateUi(QDialog *DetailDialogBase)
    {
        DetailDialogBase->setWindowTitle(tr2i18n("Log Line Details", nullptr));
#if QT_CONFIG(whatsthis)
        DetailDialogBase->setWhatsThis(tr2i18n("This dialog displays detailed information about the currently selected log line.", nullptr));
#endif // QT_CONFIG(whatsthis)
        message->setProperty("text", QVariant(tr2i18n("Message", nullptr)));
        icon->setText(tr2i18n("Icon", nullptr));
        header->setText(tr2i18n("Main information", nullptr));
#if QT_CONFIG(tooltip)
        previous->setToolTip(tr2i18n("Move to the previous line", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        previous->setWhatsThis(tr2i18n("Moves to the previous line. This button is deactivated if there is no previous log line.", nullptr));
#endif // QT_CONFIG(whatsthis)
        previous->setText(tr2i18n("&Back", nullptr));
#if QT_CONFIG(tooltip)
        next->setToolTip(tr2i18n("Move to the next line", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        next->setWhatsThis(tr2i18n("Moves to the next line. This button is deactivated if there is no next log line.", nullptr));
#endif // QT_CONFIG(whatsthis)
        next->setText(tr2i18n("&Forward", nullptr));
#if QT_CONFIG(tooltip)
        closeButton->setToolTip(tr2i18n("Close the Detail dialog.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        closeButton->setWhatsThis(tr2i18n("Closes this Detail dialog.", nullptr));
#endif // QT_CONFIG(whatsthis)
        closeButton->setText(tr2i18n("&Close", nullptr));
    } // retranslateUi

};

namespace Ui {
    class DetailDialogBase: public Ui_DetailDialogBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // DETAILDIALOGBASE_H

