/********************************************************************************
** Form generated from reading UI file 'xsessionConfigurationWidgetBase.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_XSESSIONCONFIGURATIONWIDGETBASE_H
#define UI_XSESSIONCONFIGURATIONWIDGETBASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_XSessionConfigurationWidgetBase
{
public:
    QVBoxLayout *vboxLayout;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    KUrlRequester *xsessionUrlRequester;
    QCheckBox *ignoreXorgErrors;
    QLabel *xorgErrorsDescription;
    QSpacerItem *spacerItem;

    void setupUi(QWidget *XSessionConfigurationWidgetBase)
    {
        if (XSessionConfigurationWidgetBase->objectName().isEmpty())
            XSessionConfigurationWidgetBase->setObjectName("XSessionConfigurationWidgetBase");
        XSessionConfigurationWidgetBase->resize(400, 300);
        vboxLayout = new QVBoxLayout(XSessionConfigurationWidgetBase);
        vboxLayout->setObjectName("vboxLayout");
        groupBox = new QGroupBox(XSessionConfigurationWidgetBase);
        groupBox->setObjectName("groupBox");
        verticalLayout = new QVBoxLayout(groupBox);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label = new QLabel(groupBox);
        label->setObjectName("label");

        horizontalLayout->addWidget(label);

        xsessionUrlRequester = new KUrlRequester(groupBox);
        xsessionUrlRequester->setObjectName("xsessionUrlRequester");
        xsessionUrlRequester->setEnabled(false);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(1);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(xsessionUrlRequester->sizePolicy().hasHeightForWidth());
        xsessionUrlRequester->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(xsessionUrlRequester);


        verticalLayout->addLayout(horizontalLayout);

        ignoreXorgErrors = new QCheckBox(groupBox);
        ignoreXorgErrors->setObjectName("ignoreXorgErrors");

        verticalLayout->addWidget(ignoreXorgErrors);

        xorgErrorsDescription = new QLabel(groupBox);
        xorgErrorsDescription->setObjectName("xorgErrorsDescription");
        xorgErrorsDescription->setEnabled(false);
        xorgErrorsDescription->setWordWrap(true);

        verticalLayout->addWidget(xorgErrorsDescription);


        vboxLayout->addWidget(groupBox);

        spacerItem = new QSpacerItem(20, 31, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(spacerItem);

#if QT_CONFIG(shortcut)
        label->setBuddy(xsessionUrlRequester);
#endif // QT_CONFIG(shortcut)

        retranslateUi(XSessionConfigurationWidgetBase);

        QMetaObject::connectSlotsByName(XSessionConfigurationWidgetBase);
    } // setupUi

    void retranslateUi(QWidget *XSessionConfigurationWidgetBase)
    {
        groupBox->setTitle(tr2i18n("X Session Log File", nullptr));
        label->setText(tr2i18n("&Log file:", nullptr));
#if QT_CONFIG(tooltip)
        ignoreXorgErrors->setToolTip(tr2i18n("Check this option to remove Xorg errors", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        ignoreXorgErrors->setWhatsThis(tr2i18n("Check this option to remove Xorg errors", nullptr));
#endif // QT_CONFIG(whatsthis)
        ignoreXorgErrors->setText(tr2i18n("Ignore Xorg errors", nullptr));
        xorgErrorsDescription->setText(tr2i18n("<p><b>Note:</b> Check this option to remove X.org errors.</p><p style=\"margin-bottom:0px\">The following lines will be ignored:</p>", nullptr));
        (void)XSessionConfigurationWidgetBase;
    } // retranslateUi

};

namespace Ui {
    class XSessionConfigurationWidgetBase: public Ui_XSessionConfigurationWidgetBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // XSESSIONCONFIGURATIONWIDGETBASE_H

