/*
Dialog that allows the user to send a message with the logger command
*/

/********************************************************************************
** Form generated from reading UI file 'loggerDialogBase.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_LOGGERDIALOGBASE_H
#define UI_LOGGERDIALOGBASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>
#include "QLabel"
#include "kcombobox.h"
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_LoggerDialogBase
{
public:
    QVBoxLayout *vboxLayout;
    QGroupBox *groupBox_3;
    QGridLayout *gridLayout;
    QRadioButton *messageActivation;
    QLineEdit *message;
    QRadioButton *fileActivation;
    KUrlRequester *file;
    QGroupBox *groupBox;
    QVBoxLayout *vboxLayout1;
    QHBoxLayout *hboxLayout;
    QLabel *textLabel2;
    QSpacerItem *spacerItem;
    KComboBox *priority;
    QHBoxLayout *hboxLayout1;
    QLabel *textLabel2_2;
    QSpacerItem *spacerItem1;
    KComboBox *facility;
    QGroupBox *groupBox_2;
    QVBoxLayout *vboxLayout2;
    QHBoxLayout *hboxLayout2;
    QCheckBox *tagActivation;
    QLineEdit *tag;
    QCheckBox *useProcessIdentifier;
    QSpacerItem *spacerItem2;
    QHBoxLayout *hboxLayout3;
    QLabel *loggerManual;
    QSpacerItem *spacerItem3;
    QPushButton *buttonOK;
    QPushButton *buttonCancel;

    void setupUi(QDialog *LoggerDialogBase)
    {
        if (LoggerDialogBase->objectName().isEmpty())
            LoggerDialogBase->setObjectName("LoggerDialogBase");
        LoggerDialogBase->resize(440, 429);
        LoggerDialogBase->setBaseSize(QSize(300, 300));
        LoggerDialogBase->setAcceptDrops(true);
        LoggerDialogBase->setSizeGripEnabled(false);
        vboxLayout = new QVBoxLayout(LoggerDialogBase);
        vboxLayout->setObjectName("vboxLayout");
        groupBox_3 = new QGroupBox(LoggerDialogBase);
        groupBox_3->setObjectName("groupBox_3");
        gridLayout = new QGridLayout(groupBox_3);
        gridLayout->setObjectName("gridLayout");
        messageActivation = new QRadioButton(groupBox_3);
        messageActivation->setObjectName("messageActivation");
        messageActivation->setChecked(true);

        gridLayout->addWidget(messageActivation, 0, 0, 1, 1);

        message = new QLineEdit(groupBox_3);
        message->setObjectName("message");

        gridLayout->addWidget(message, 0, 1, 1, 2);

        fileActivation = new QRadioButton(groupBox_3);
        fileActivation->setObjectName("fileActivation");

        gridLayout->addWidget(fileActivation, 1, 0, 1, 2);

        file = new KUrlRequester(groupBox_3);
        file->setObjectName("file");
        file->setEnabled(false);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(1);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(file->sizePolicy().hasHeightForWidth());
        file->setSizePolicy(sizePolicy);

        gridLayout->addWidget(file, 1, 2, 1, 1);


        vboxLayout->addWidget(groupBox_3);

        groupBox = new QGroupBox(LoggerDialogBase);
        groupBox->setObjectName("groupBox");
        vboxLayout1 = new QVBoxLayout(groupBox);
        vboxLayout1->setObjectName("vboxLayout1");
        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        textLabel2 = new QLabel(groupBox);
        textLabel2->setObjectName("textLabel2");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(textLabel2->sizePolicy().hasHeightForWidth());
        textLabel2->setSizePolicy(sizePolicy1);
        textLabel2->setWordWrap(false);

        hboxLayout->addWidget(textLabel2);

        spacerItem = new QSpacerItem(84, 24, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        hboxLayout->addItem(spacerItem);

        priority = new KComboBox(groupBox);
        priority->setObjectName("priority");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(1);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(priority->sizePolicy().hasHeightForWidth());
        priority->setSizePolicy(sizePolicy2);

        hboxLayout->addWidget(priority);


        vboxLayout1->addLayout(hboxLayout);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setObjectName("hboxLayout1");
        hboxLayout1->setContentsMargins(0, 0, 0, 0);
        textLabel2_2 = new QLabel(groupBox);
        textLabel2_2->setObjectName("textLabel2_2");
        sizePolicy1.setHeightForWidth(textLabel2_2->sizePolicy().hasHeightForWidth());
        textLabel2_2->setSizePolicy(sizePolicy1);
        textLabel2_2->setWordWrap(false);

        hboxLayout1->addWidget(textLabel2_2);

        spacerItem1 = new QSpacerItem(84, 24, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        hboxLayout1->addItem(spacerItem1);

        facility = new KComboBox(groupBox);
        facility->setObjectName("facility");
        sizePolicy2.setHeightForWidth(facility->sizePolicy().hasHeightForWidth());
        facility->setSizePolicy(sizePolicy2);

        hboxLayout1->addWidget(facility);


        vboxLayout1->addLayout(hboxLayout1);


        vboxLayout->addWidget(groupBox);

        groupBox_2 = new QGroupBox(LoggerDialogBase);
        groupBox_2->setObjectName("groupBox_2");
        vboxLayout2 = new QVBoxLayout(groupBox_2);
        vboxLayout2->setObjectName("vboxLayout2");
        hboxLayout2 = new QHBoxLayout();
        hboxLayout2->setObjectName("hboxLayout2");
        hboxLayout2->setContentsMargins(0, 0, 0, 0);
        tagActivation = new QCheckBox(groupBox_2);
        tagActivation->setObjectName("tagActivation");
        tagActivation->setFocusPolicy(Qt::TabFocus);

        hboxLayout2->addWidget(tagActivation);

        tag = new QLineEdit(groupBox_2);
        tag->setObjectName("tag");

        hboxLayout2->addWidget(tag);


        vboxLayout2->addLayout(hboxLayout2);

        useProcessIdentifier = new QCheckBox(groupBox_2);
        useProcessIdentifier->setObjectName("useProcessIdentifier");
        useProcessIdentifier->setChecked(true);

        vboxLayout2->addWidget(useProcessIdentifier);


        vboxLayout->addWidget(groupBox_2);

        spacerItem2 = new QSpacerItem(31, 31, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(spacerItem2);

        hboxLayout3 = new QHBoxLayout();
        hboxLayout3->setObjectName("hboxLayout3");
        hboxLayout3->setContentsMargins(0, 0, 0, 0);
        loggerManual = new QLabel(LoggerDialogBase);
        loggerManual->setObjectName("loggerManual");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(loggerManual->sizePolicy().hasHeightForWidth());
        loggerManual->setSizePolicy(sizePolicy3);

        hboxLayout3->addWidget(loggerManual);

        spacerItem3 = new QSpacerItem(155, 26, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        hboxLayout3->addItem(spacerItem3);

        buttonOK = new QPushButton(LoggerDialogBase);
        buttonOK->setObjectName("buttonOK");
        buttonOK->setEnabled(false);
        buttonOK->setAutoDefault(true);

        hboxLayout3->addWidget(buttonOK);

        buttonCancel = new QPushButton(LoggerDialogBase);
        buttonCancel->setObjectName("buttonCancel");
        buttonCancel->setAutoDefault(true);

        hboxLayout3->addWidget(buttonCancel);


        vboxLayout->addLayout(hboxLayout3);

#if QT_CONFIG(shortcut)
        textLabel2->setBuddy(priority);
        textLabel2_2->setBuddy(facility);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(buttonOK, buttonCancel);
        QWidget::setTabOrder(buttonCancel, loggerManual);

        retranslateUi(LoggerDialogBase);

        buttonOK->setDefault(true);


        QMetaObject::connectSlotsByName(LoggerDialogBase);
    } // setupUi

    void retranslateUi(QDialog *LoggerDialogBase)
    {
        LoggerDialogBase->setWindowTitle(tr2i18n("Log Message", nullptr));
        groupBox_3->setTitle(tr2i18n("Message", nullptr));
        messageActivation->setText(tr2i18n("&Message:", nullptr));
        fileActivation->setText(tr2i18n("&File content:", nullptr));
        groupBox->setTitle(tr2i18n("Properties", nullptr));
        textLabel2->setText(tr2i18n("&Priority:", nullptr));
        textLabel2_2->setText(tr2i18n("&Facility:", nullptr));
        groupBox_2->setTitle(tr2i18n("Options", nullptr));
        tagActivation->setText(tr2i18n("&Tag:", nullptr));
        useProcessIdentifier->setText(tr2i18n("Log process &identifier", nullptr));
#if QT_CONFIG(tooltip)
        loggerManual->setToolTip(tr2i18n("Open the 'logger' command manual.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        loggerManual->setStatusTip(tr2i18n("This link opens the 'logger' command manual.", nullptr));
#endif // QT_CONFIG(statustip)
        loggerManual->setText(tr2i18n("<a href=\"man:/logger\">Logger Manual</a>", nullptr));
        buttonOK->setText(tr2i18n("&OK", nullptr));
#if QT_CONFIG(shortcut)
        buttonOK->setShortcut(QString());
#endif // QT_CONFIG(shortcut)
        buttonCancel->setText(tr2i18n("&Cancel", nullptr));
#if QT_CONFIG(shortcut)
        buttonCancel->setShortcut(QString());
#endif // QT_CONFIG(shortcut)
    } // retranslateUi

};

namespace Ui {
    class LoggerDialogBase: public Ui_LoggerDialogBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // LOGGERDIALOGBASE_H

