/********************************************************************************
** Form generated from reading UI file 'fileListBase.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FILELISTBASE_H
#define UI_FILELISTBASE_H

#include <QtCore/QVariant>
#include <QtGui/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_FileListBase
{
public:
    QAction *addAction;
    QVBoxLayout *vboxLayout;
    QLabel *description;
    QGroupBox *filesBox;
    QGridLayout *gridLayout;
    QVBoxLayout *vboxLayout1;
    QPushButton *add;
    QPushButton *modify;
    QPushButton *remove;
    QPushButton *removeAll;
    QPushButton *up;
    QPushButton *down;
    QSpacerItem *spacerItem;
    QLabel *notes;
    QListWidget *fileList;

    void setupUi(QWidget *FileListBase)
    {
        if (FileListBase->objectName().isEmpty())
            FileListBase->setObjectName("FileListBase");
        FileListBase->resize(487, 476);
        FileListBase->setBaseSize(QSize(200, 400));
        addAction = new QAction(FileListBase);
        addAction->setObjectName("addAction");
        vboxLayout = new QVBoxLayout(FileListBase);
        vboxLayout->setObjectName("vboxLayout");
        vboxLayout->setContentsMargins(0, 0, 0, -1);
        description = new QLabel(FileListBase);
        description->setObjectName("description");
        description->setAlignment(Qt::AlignJustify|Qt::AlignVCenter);
        description->setWordWrap(true);

        vboxLayout->addWidget(description);

        filesBox = new QGroupBox(FileListBase);
        filesBox->setObjectName("filesBox");
        gridLayout = new QGridLayout(filesBox);
        gridLayout->setObjectName("gridLayout");
        vboxLayout1 = new QVBoxLayout();
        vboxLayout1->setObjectName("vboxLayout1");
        add = new QPushButton(filesBox);
        add->setObjectName("add");

        vboxLayout1->addWidget(add);

        modify = new QPushButton(filesBox);
        modify->setObjectName("modify");

        vboxLayout1->addWidget(modify);

        remove = new QPushButton(filesBox);
        remove->setObjectName("remove");

        vboxLayout1->addWidget(remove);

        removeAll = new QPushButton(filesBox);
        removeAll->setObjectName("removeAll");

        vboxLayout1->addWidget(removeAll);

        up = new QPushButton(filesBox);
        up->setObjectName("up");
        up->setEnabled(true);

        vboxLayout1->addWidget(up);

        down = new QPushButton(filesBox);
        down->setObjectName("down");

        vboxLayout1->addWidget(down);

        spacerItem = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::MinimumExpanding);

        vboxLayout1->addItem(spacerItem);


        gridLayout->addLayout(vboxLayout1, 0, 1, 1, 1);

        notes = new QLabel(filesBox);
        notes->setObjectName("notes");
        notes->setWordWrap(true);

        gridLayout->addWidget(notes, 1, 0, 1, 2);

        fileList = new QListWidget(filesBox);
        fileList->setObjectName("fileList");
        fileList->setContextMenuPolicy(Qt::ActionsContextMenu);
        fileList->setDragDropMode(QAbstractItemView::InternalMove);

        gridLayout->addWidget(fileList, 0, 0, 1, 1);


        vboxLayout->addWidget(filesBox);


        retranslateUi(FileListBase);

        QMetaObject::connectSlotsByName(FileListBase);
    } // setupUi

    void retranslateUi(QWidget *FileListBase)
    {
        addAction->setText(tr2i18n("add", nullptr));
        description->setText(tr2i18n("File List Description", nullptr));
        filesBox->setTitle(tr2i18n("Log Files", nullptr));
#if QT_CONFIG(tooltip)
        add->setToolTip(tr2i18n("<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Sans Serif'; font-size:9pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Choose a new file</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        add->setWhatsThis(tr2i18n("<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Sans Serif'; font-size:9pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Opens a dialog box to choose a new file to be added to the list.</p></body></html>", nullptr));
#endif // QT_CONFIG(whatsthis)
        add->setText(tr2i18n("&Add File...", nullptr));
        modify->setText(tr2i18n("&Modify File...", nullptr));
#if QT_CONFIG(tooltip)
        remove->setToolTip(tr2i18n("<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Sans Serif'; font-size:9pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Delete the current file(s)</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        remove->setWhatsThis(tr2i18n("<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Sans Serif'; font-size:9pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Deletes the files selected on the list.</p></body></html>", nullptr));
#endif // QT_CONFIG(whatsthis)
        remove->setText(tr2i18n("&Remove", nullptr));
#if QT_CONFIG(tooltip)
        removeAll->setToolTip(tr2i18n("<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Sans Serif'; font-size:9pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Remove all files</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        removeAll->setWhatsThis(tr2i18n("<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Sans Serif'; font-size:9pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Remove all the files on the list, even if they are not selected.</p></body></html>", nullptr));
#endif // QT_CONFIG(whatsthis)
        removeAll->setText(tr2i18n("Rem&ove All", nullptr));
#if QT_CONFIG(tooltip)
        up->setToolTip(tr2i18n("<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Sans Serif'; font-size:9pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Move up the current file(s)</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        up->setWhatsThis(tr2i18n("<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Sans Serif'; font-size:9pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Moves the selected files up in the list. This option allows the files to be read <span style=\" font-weight:600;\">in first</span> by KSystemLog.</p></body></html>", nullptr));
#endif // QT_CONFIG(whatsthis)
        up->setText(tr2i18n("Move &Up", nullptr));
#if QT_CONFIG(tooltip)
        down->setToolTip(tr2i18n("<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Sans Serif'; font-size:9pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Move down the current file(s)</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        down->setWhatsThis(tr2i18n("<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Sans Serif'; font-size:9pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Moves the selected files down in the list. This option allows the files to be read <span style=\" font-weight:600;\">in last</span> by KSystemLog.</p></body></html>", nullptr));
#endif // QT_CONFIG(whatsthis)
        down->setText(tr2i18n("Move &Down", nullptr));
        notes->setText(tr2i18n("<p style='margin-top:0px;margin-bottom:0px;'><b>Notes:</b></p><ul style='margin-top:0px'><li>Files are read using the order of this list.</li><li>Compressed and plain text files are accepted <i>(*.log, *.gz, *.bz2,...)</i>.</li><li>Use the <b>'*'</b> wildcard to select multiple log files when adding files.</li></ul>", nullptr));
#if QT_CONFIG(tooltip)
        fileList->setToolTip(tr2i18n("<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Sans Serif'; font-size:9pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">List of files used by this log type.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        fileList->setWhatsThis(tr2i18n("<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Sans Serif'; font-size:9pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Here is a list of every file that will be read by KSystemLog to display the current log lines.</p></body></html>", nullptr));
#endif // QT_CONFIG(whatsthis)
        (void)FileListBase;
    } // retranslateUi

};

namespace Ui {
    class FileListBase: public Ui_FileListBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // FILELISTBASE_H

