// This file is generated by kconfig_compiler_kf6 from ksystemlog.kcfg.
// All changes you do to this file will be lost.

#include "ksystemlogConfig.h"

#include <qglobal.h>
#include <QFile>

class KSystemLogConfigHelper
{
  public:
    KSystemLogConfigHelper() : q(nullptr) {}
    ~KSystemLogConfigHelper() { delete q; q = nullptr; }
    KSystemLogConfigHelper(const KSystemLogConfigHelper&) = delete;
    KSystemLogConfigHelper& operator=(const KSystemLogConfigHelper&) = delete;
    KSystemLogConfig *q;
};
Q_GLOBAL_STATIC(KSystemLogConfigHelper, s_globalKSystemLogConfig)
KSystemLogConfig *KSystemLogConfig::self()
{
  if (!s_globalKSystemLogConfig()->q) {
    new KSystemLogConfig;
    s_globalKSystemLogConfig()->q->read();
  }

  return s_globalKSystemLogConfig()->q;
}

KSystemLogConfig::KSystemLogConfig( )
  : KConfigSkeleton( QStringLiteral( "ksystemlogrc" ) )
{
  Q_ASSERT(!s_globalKSystemLogConfig()->q);
  s_globalKSystemLogConfig()->q = this;
  setCurrentGroup( QStringLiteral( "KSystemLogGeneral" ) );

  KConfigSkeleton::ItemString  *itemStartupLogMode;
  itemStartupLogMode = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "StartupLogMode" ), mStartupLogMode, QStringLiteral( "journaldLogMode" ) );
  addItem( itemStartupLogMode, QStringLiteral( "StartupLogMode" ) );
  KConfigSkeleton::ItemInt  *itemMaxLines;
  itemMaxLines = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "MaxLines" ), mMaxLines, 1000 );
  addItem( itemMaxLines, QStringLiteral( "MaxLines" ) );
  KConfigSkeleton::ItemBool  *itemDeleteDuplicatedLines;
  itemDeleteDuplicatedLines = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "DeleteDuplicatedLines" ), mDeleteDuplicatedLines, false );
  addItem( itemDeleteDuplicatedLines, QStringLiteral( "DeleteDuplicatedLines" ) );
  KConfigSkeleton::ItemBool  *itemDeleteProcessIdentifier;
  itemDeleteProcessIdentifier = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "DeleteProcessIdentifier" ), mDeleteProcessIdentifier, false );
  addItem( itemDeleteProcessIdentifier, QStringLiteral( "DeleteProcessIdentifier" ) );
  KConfigSkeleton::ItemBool  *itemColorizeLogLines;
  itemColorizeLogLines = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ColorizeLogLines" ), mColorizeLogLines, true );
  addItem( itemColorizeLogLines, QStringLiteral( "ColorizeLogLines" ) );
  KConfigSkeleton::ItemBool  *itemTooltipEnabled;
  itemTooltipEnabled = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "TooltipEnabled" ), mTooltipEnabled, true );
  addItem( itemTooltipEnabled, QStringLiteral( "TooltipEnabled" ) );
  KConfigSkeleton::ItemBool  *itemNewLinesDisplayed;
  itemNewLinesDisplayed = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "NewLinesDisplayed" ), mNewLinesDisplayed, true );
  addItem( itemNewLinesDisplayed, QStringLiteral( "NewLinesDisplayed" ) );
  KConfigSkeleton::ItemBool  *itemToggleFilterBar;
  itemToggleFilterBar = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ToggleFilterBar" ), mToggleFilterBar, true );
  addItem( itemToggleFilterBar, QStringLiteral( "ToggleFilterBar" ) );
  QList<KConfigSkeleton::ItemEnum::Choice> valuesDateFormat;
  KConfigSkeleton::ItemEnum  *itemDateFormat;
  itemDateFormat = new KConfigSkeleton::ItemEnum( currentGroup(), QStringLiteral( "DateFormat" ), mDateFormat, valuesDateFormat, QLocale::ShortFormat );
  addItem( itemDateFormat, QStringLiteral( "DateFormat" ) );
}

KSystemLogConfig::~KSystemLogConfig()
{
  if (s_globalKSystemLogConfig.exists() && !s_globalKSystemLogConfig.isDestroyed()) {
    s_globalKSystemLogConfig()->q = nullptr;
  }
}

